<?php

/**
 * @file
 *  admin effects of the superslide module.
 *
 */

/**
 * Form with overview of all superslide effect.
 */
function superslide_effect_add_form($form, &$form_state) {

  // get superslide effect.
  $rows = array();
  $effects = superslide_get_effects(NULL);

  foreach ($effects as $effect) {
    $rows[] = array(
      'name' => check_plain($effect->name),
      'type' => $effect->type,
      'edit' => l(t('Edit'), "admin/structure/superslide/edit/$effect->sid"),
      'delete' => l(t('Delete'), "admin/structure/superslide/delete/$effect->sid"),
      'effect' => l(t('Configure effect'), "admin/structure/superslide/$effect->sid/configure"),
    );
  }
  if (empty($rows)) {
    $rows[] = array(array(
        'data' => t('No superslide effect available.'),
        'colspan' => '5',
      ));
  }

  $header = array(t('Name'), t('Type'), array(
      'data' => t('Operation'),
      'colspan' => '3',
    ));
  $output = theme('table', array('header' => $header, 'rows' => $rows, 'attributes' => array('id' => 'superslide')));

  $form = array();
  $form['list'] = array(
    '#type' => 'fieldset',
    '#title' => t('superslide effect'),
    '#collapsible' => TRUE,
  );
  $form['list']['table'] = array(
    '#type' => 'item',
    '#prefix' => '<div>',
    '#markup' => $output,
    '#suffix' => '</div>',
  );

  // add superslide effect.
  $form['effect'] = array(
    '#type' => 'fieldset',
    '#title' => t('Add superslide effect.'),
  );

  $form['effect']['name'] = array(
    '#type' => 'textfield',
    '#title' => t('Effect name'),
    '#description' => t('A effect with this same name will be created.'),
    '#default_value' => '',
    '#required' => TRUE,
  );
  $all_types = superslide_get_types();
  if(!empty($all_types)){
    $form['effect']['type'] = array(
      '#type' => 'select',
      '#title' => t('Type of superslide effect'),
      '#default_value' => 'superslide_slide',   
      '#options' => superslide_get_types(),
      '#required' => TRUE,
    );
  }

  $form['effect']['op'] = array(
    '#type' => 'submit',
    '#value' => t('Add effect'),
  );

  return $form;
}

/**
 * Validate "Add Effect" form.
 */
function superslide_effect_add_form_validate($form, &$form_state) {
  $effects = superslide_get_effects(NULL);
  $effect_name = array();
  foreach ($effects as $effect) {
    $effect_name[] = $effect->name;
  }

  if (!empty($effect_name)) {
    // Check if name is unique
    if (in_array($form_state['values']['name'], $effect_name)) {
      form_set_error('', t('Superslide effect %s already exists. Please use a different name.', array('%s' => $form_state['values']['name'])));
    }
  }
}
/**
 * Add superslide effect to database from "Add Effect" form.
 */
function superslide_effect_add_form_submit($form, &$form_state) {
  $id = db_insert('superslide_effects')
  ->fields(array(
    'name' => $form_state['values']['name'],
    'type' => $form_state['values']['type'],
  ))
  ->execute();

  drupal_set_message(t('Superslide effect %s added.', array('%s' => $form_state['values']['name'])));
}

/**
 * Edit effect form.
 */
function superslide_effect_edit_form($form, &$form_state, $sid) {
  $effect = superslide_get_effects($sid);
  $form = array();

  $form['sid'] = array(
    '#type' => 'hidden',
    '#value' => $sid,
  );

  $form['name'] = array(
    '#type' => 'textfield',
    '#title' => t('Effect name'),
    '#description' => t('The effect name must be unique.'),
    '#default_value' => $effect->name,
    '#required' => TRUE,
  );

  $form['type'] = array(
    '#type' => 'select',
    '#title' => t('Type of superslide effect'),
    '#default_value' => $effect->type,   
    '#options' => superslide_get_types(),
    '#required' => TRUE,
  );

  $form['op'] = array(
    '#type' => 'submit',
    '#value' => t('Save'),
  );

  return $form;
}

/**
 * Validate edit effect form.
 */
function superslide_effect_edit_form_validate($form, &$form_state) {
  $effects = superslide_get_effects(NULL);
  $effect_name = array();
  foreach ($effects as $effect) {
    $effect_name[$effect->sid] = $effect->name;
  }

  // Remove current effect name to prevent false error.
  unset($effect_name[$form_state['values']['sid']]);

  if (!empty($effect_name)) {
    // Check if name is unique.
    if (in_array($form_state['values']['name'], $effect_name)) {
      form_set_error('', t('Superslide effect %s already exists. Please use a different name.', array('%s' => $form_state['values']['name'])));
    }
  }
}

/**
 * Submit edit effect form.
 */
function superslide_effect_edit_form_submit($form, &$form_state) {
  db_update('superslide_effects')
  ->fields(array(
    'name' => $form_state['values']['name'],
    'type' => $form_state['values']['type'],
  ))
  ->condition('sid', $form_state['values']['sid'])
  ->execute();

  drupal_set_message(t('Superslide effect updated.'));
  $form_state['redirect'] = 'admin/structure/superslide';
  return $form;
}

/**
 * Delete effect form.
 */
function superslide_effect_confirm_delete_form($form, &$form_state, $sid) {
  $effect = superslide_get_effects($sid);
  if (empty($effect)) {
    drupal_set_message(t('The effect with sid @sid was not found.', array('@sid' => $sid)), 'error');
    return array();
  }
  else {
    if ($effect->enabled == 1) {

      //The question to ask the user.
      $question = t('Are you sure you want to delete the superslide effect %name?', array('%name' => $effect->name));
    }
    else {
      //The question to ask the user.
      $question = t('Are you sure you want to delete the superslide effect %name?', array('%name' => $effect->name));
    }
    // The page to go to if the user denies the action.
    $path = 'admin/structure/superslide';

    // Additional text to display (defaults to "This action cannot be undone.").
    $description = t('This action cannot be undone.');

    // A caption for the button which confirms the action.
    $yes = t('Delete');

    // A caption for the link which denies the action.
    $no = t('Cancel');

    // set sid value to use in submit function.
    $form['sid'] = array(
      '#type' => 'value',
      '#value' => $sid,
    );

    // set the redirect path value to use in submit function.
    $form_state['redirect'] = $path;
    return confirm_form(
      $form,
      $question,
      $path,
      $description,
      $yes,
      $no
    );
  }
}

/**
 * Delete a superslide effect.
 */
function superslide_effect_confirm_delete_form_submit($form, &$form_state) {

  if (superslide_effect_confirm_delete($form_state['values']['sid'])) {
    $succes_message = t('Superslide effect successfully deleted!');
    drupal_set_message($succes_message);
  }
  else {
    $failure_message = t('There was a problem deleting the superslide effect');
    drupal_set_message($failure_message);
  }
  $form_state['redirect'] = 'admin/structure/superslide';
  return $form;
}

/**
 * Delete a superslide effect from the database.
 */
function superslide_effect_confirm_delete($sid) {
  $result = db_delete('superslide_effects')
  ->condition('sid', (int) $sid)
  ->execute();

  // variable_del includes a clear cache.
  variable_del('superslide_effect_' . $sid . '_settings');
  variable_del('superslide_effect_' . $sid . '_cycle_settings');
  variable_del('superslide_effect_' . $sid . '_cycle_mapping_settings');

  return TRUE;
}

/**
 * Config effect form.
 */
function superslide_effect_config_form($form, &$form_state, $sid) {
  $effect = superslide_get_effects($sid);
  $all_types = superslide_types_list_all();
  
  if(!empty($effect->js_code)){
    $js_params = explode(",", $effect->js_code);
    if(!empty($js_params)){
      foreach ($js_params as $param) {
        if ($trimmed_param = trim($param)) {
          $items = explode(':',$trimmed_param);
          $cur_params[$items[0]] = substr($items[1], 1, -1);       
        }
      }
    }
  }

  // Load superslide css and js.
  drupal_add_css(drupal_get_path('module', 'superslide') . '/css/superslide.css');
  drupal_add_js(drupal_get_path('module', 'superslide') . '/js/jquery.superslide.js');
  drupal_add_js(drupal_get_path('module', 'superslide') . '/js/superslide.js');

  $form = array();
  
  $form['back_to_list'] = array(
    '#type' => 'markup',
    '#markup' => '<div class="backlist">' .l('Back List', 'admin/structure/superslide/list'). '</div>',
  );

  $form['title'] = array(
    '#type' => 'markup',
    '#prefix' => '<div class="demoBox">',
    '#markup' => '<div name="effect2" id="effect2" class="hd"><h3>'.$all_types[$effect->type]['name'].'</h3></div>',
  );

  $form['preview'] = array(
    '#type' => 'markup',
    '#markup' => '<iframe scrolling="no" src="'.base_path().'superslide/'.$sid.'/preview?" frameborder="0"></iframe>',
  );

  $form['params'] = array(
    '#type' => 'fieldset',
    '#title' => t('General Parameters (switch to see)'),
    '#collapsible' => TRUE,
    '#attributes' => array('class' => array('params')),
  );

  foreach ($all_types[$effect->type]['params'] as $key => $param) {
    if($param['type'] == 'hidden'){
      $form['params'][$key] = array(
        '#type' => $param['type'],
        '#value' => $param['value'],  
      );
    }else{
      $form['params'][$key] = array(
        '#type' => $param['type'],
        '#options' => drupal_map_assoc($param['options']),
        '#title' => $param['title'],
        '#default_value' => isset($cur_params[$key]) ? $cur_params[$key] : key(drupal_map_assoc($param['options'])),    
      );
    }
  }

  $form['params']['curJsCode'] = array(
    '#type' => 'markup',
    '#prefix' => '<div class="curcall"><label>Call Code: </label><span class="curJsCode">',
    '#suffix' => '</span></div>',
    '#markup' => 'jQuery(".superslideBox").slide({<i></i>});',
  );

  $form['params']['css_path'] = array(
    '#type' => 'textfield',
    '#title' => t('Css Path'),
    '#maxlength' => 255,
    '#description' => t('The current CSS path of this effect.'),
    '#default_value' => !empty($effect->css_path) ? $effect->css_path : $all_types[$effect->type]['css file'],
  );

  $form['params']['note'] = array(
    '#type' => 'markup',    
    '#prefix' => '<div class="note">',
    '#suffix' => '</div></div>',
    '#markup' => 'Note: easing effect for fade little effect; easing effect of different settings appropriate "effect speed", there will be the best results.',
  );

  $form['sid'] = array(
    '#type' => 'hidden',
    '#value' => $sid,
  );

  $form['op'] = array(
    '#type' => 'submit',
    '#value' => t('Save'),
  );

  return $form;
}

/**
 * Submit config effect form.
 */
function superslide_effect_config_form_submit($form, &$form_state) {
  if(isset($form_state['values']) && !empty($form_state['values']) && !empty($form_state['values']['sid'])) {
    $js_params = '';
    $effect = superslide_get_effects($form_state['values']['sid']);
    $all_types = superslide_types_list_all();

    foreach ($all_types[$effect->type]['params'] as $key => $param) {
      if(!empty($form_state['values'][$key])){
        $js_params .= $key.':"'.$form_state['values'][$key].'",';
      }
    }
  }

  if(!empty($form_state['values']['sid'])){
    db_update('superslide_effects')
    ->fields(array(
      'js_code' => $js_params,
      'css_path' => $form_state['values']['css_path'],
    ))
    ->condition('sid', $form_state['values']['sid'])
    ->execute();
  }

  drupal_set_message(t('Superslide effect config successfully.'));
  $form_state['redirect'] = 'admin/structure/superslide';
  return $form;
}

/**
 * superslide settings form.
 */
function superslide_settings_form($form, &$form_state) {
  $form = array();

  $form['superslide_node_type'] = array(
    '#type' => 'textfield',
    '#title' => t('Effect name'),
    '#description' => t('The effect name must be unique.'),
    '#default_value' => '',
    '#required' => TRUE,
  );

  $form_state['redirect'] = 'admin/structure/superslide/list';

  return system_settings_form($form);
}
