<?php
/**
 * @file
 * Definition of superslide_plugin_style.
 */

/**
 * Class to define a style plugin handler.
 */
class SuperslideAccordionPluginStyle extends views_plugin_style {
  /**
   * Definition.
   */
  public function option_definition() {
    $options = parent::option_definition();
    // Superslide option definition.
    $options['title_field'] = array('default' => NULL);
    $options['superslide'] = array(
      'contains' => array(
        'enable' => array('default' => TRUE, 'bool' => TRUE),
        'options' => array(
          'type' => array('default' => ''),
          'effect' => array('default' => ''),
        ),        
      ),
    );
    return $options;
  }

  /**
   * Form.
   */
  function options_form(&$form, &$form_state) {
    parent::options_form($form, $form_state);

    if (isset($form['grouping'])) {
      $options = array();
      foreach (element_children($form['grouping']) as $key => $value) {
        if (!empty($form['grouping'][$key]['field']['#options']) && is_array($form['grouping'][$key]['field']['#options'])) {
          $options = array_merge($options, $form['grouping'][$key]['field']['#options']);
        }
      }

      // Delete grouping.
      unset($form['grouping']);

      $form['title_field'] = array(
        '#type' => 'select',
        '#title' => t('Title field'),
        '#options' => $options,
        '#required' => TRUE,
        '#default_value' => $this->options['title_field'],
        '#description' => t('Select the field that will be used as the title.'),
      );
    }
    
    //Load css
    drupal_add_css(drupal_get_path('module', 'superslide') . '/css/superslide.css');
   
    $form['superslide'] = array(
      '#type' => 'fieldset',
      '#attributes' => array('class' => array('views-attachment', 'fieldset-no-legend'),),
      '#tree' => TRUE,
    );
    $form['superslide']['enable'] = array(
      '#type' => 'checkbox',
      '#title' => t('Enable SuperSlide'),
      '#description' => t('If you enable this, you can add a special effects for this output.'),
      '#default_value' => $this->options['superslide']['enable'],
      '#id' => 'edit-enable-superslide',
    );
    $form['superslide']['options'] = array(
      '#type' => 'container',
      '#attributes' => array('class' => array('options-set'),),
      '#dependency' => array(
        'edit-enable-superslide' => array(1),
      ),
      '#pre_render' => array('ctools_dependent_pre_render'),
      '#prefix' => '<div id="edit-options-wrapper">',
      '#suffix' => '</div>',
    );
    $form['superslide']['options']['type'] = array(
      '#type' => 'select',
      '#title' => 'Type of Superslide',
      '#options' => drupal_map_assoc(array('superslide_accordion')),
      '#default_value' => $this->options['superslide']['options']['type'],
    );    
    $form['superslide']['options']['superslide_accordion'] = array(
      '#type' => 'select',
      '#title' =>t("@name Effect", array('@name' => $type)),
      '#options' => superslide_get_effects_by_type('superslide_accordion'),
      '#default_value' => $this->options['superslide']['options']['superslide_accordion'] ? $this->options['superslide']['options']['superslide_accordion'] : '-none-',
    );    
  }
}
