<?php
/**
 * @file
 * Definition of superslide_plugin_style.
 */

/**
 * Class to define a style plugin handler.
 */
class SuperslideMenuPluginStyle extends views_plugin_style {
  /**
   * Definition.
   */
  public function option_definition() {
    $options = parent::option_definition();
    $options['superslide_menu_menu'] = array('default' => 'navigation:0');
    $options['superslide_menu_depth'] = array('default' => NULL);
    $options['superslide_menu_respect_expand'] = array('default' => NULL);
    // Superslide option definition.
    $options['superslide'] = array(
      'contains' => array(
        'enable' => array('default' => TRUE, 'bool' => TRUE),
        'options' => array(
          'type' => array('default' => ''),
          'effect' => array('default' => ''),
        ),        
      ),
    );
    return $options;
  }

  /**
   * Form.
   */
  function options_form(&$form, &$form_state) {
    parent::options_form($form, $form_state);

    $form['superslide_menu_menu'] = array(
      '#type' => 'select',
      '#title' => t('Menu parent'),
      '#description' => t('The menu parent from which to show a superslide menu.'),
      '#default_value' => $this->options['superslide_menu_menu'],
      '#options' => menu_parent_options(menu_get_menus(), 0),
    );
    $form['superslide_menu_depth'] = array(
      '#type' => 'select',
      '#title' => t('Menu depth'),
      '#description' => t('The depth of the menu, i.e. the number of child levels starting with the parent selected above. Leave set to -1 to display all children and use 0 to display no children.'),
      '#default_value' => $this->options['superslide_menu_depth'],
      '#options' => drupal_map_assoc(range(-1, 5)),
    );
    $form['superslide_menu_respect_expand'] = array(
      '#type' => 'select',
      '#title' => t('Respect "Show as expanded" option'),
      '#description' => t('Menu items have a "Show as expanded" option, which is disabled by default. Since menu items do NOT have this option checked by default, you should choose Yes here once you have configured the menu items that you DO want to expand.'),
      '#options' => array(
        0 => t('No'),
        1 => t('Yes'),
      ),
      '#default_value' => $this->options['superslide_menu_respect_expand'],
    );

    //Load css
    drupal_add_css(drupal_get_path('module', 'superslide') . '/css/superslide.css');

    $form['superslide'] = array(
      '#type' => 'fieldset',
      '#attributes' => array('class' => array('views-attachment', 'fieldset-no-legend'),),
      '#tree' => TRUE,
    );
    $form['superslide']['enable'] = array(
      '#type' => 'checkbox',
      '#title' => t('Enable SuperSlide'),
      '#description' => t('If you enable this, you can add a special effects for this output.'),
      '#default_value' => $this->options['superslide']['enable'],
      '#id' => 'edit-enable-superslide',
    );
    $form['superslide']['options'] = array(
      '#type' => 'container',
      '#attributes' => array('class' => array('options-set'),),
      '#dependency' => array(
        'edit-enable-superslide' => array(1),
      ),
      '#pre_render' => array('ctools_dependent_pre_render'),
      '#prefix' => '<div id="edit-options-wrapper">',
      '#suffix' => '</div>',
    );
    $form['superslide']['options']['type'] = array(
      '#type' => 'select',
      '#title' => 'Type of Superslide',
      '#options' => drupal_map_assoc(array('superslide_menu')),
      '#default_value' => $this->options['superslide']['options']['type'],
    );    
    $form['superslide']['options']['superslide_menu'] = array(
      '#type' => 'select',
      '#title' =>t("@name Effect", array('@name' => $type)),
      '#options' => superslide_get_effects_by_type('superslide_menu'),
      '#default_value' => $this->options['superslide']['options']['superslide_menu'] ? $this->options['superslide']['options']['superslide_menu'] : '-none-',
    );
  }
}
